Module: Kernel
- Defined in:
- lib/configuratron/blank_slate.rb
Class Method Summary collapse
- .blank_slate_method_added ⇒ Object
-
.method_added(name) ⇒ Object
Detect method additions to Kernel and remove them in the BlankSlate class.
Class Method Details
.blank_slate_method_added ⇒ Object
33 |
# File 'lib/configuratron/blank_slate.rb', line 33 alias_method :blank_slate_method_added, :method_added |
.method_added(name) ⇒ Object
Detect method additions to Kernel and remove them in the BlankSlate class.
37 38 39 40 41 42 |
# File 'lib/configuratron/blank_slate.rb', line 37 def method_added(name) result = blank_slate_method_added(name) return result if self != Kernel BlankSlate.hide(name) result end |